Documentation
¶
Overview ¶
This has been run against a keybag from Manifest.plist in an iOS backup. It will probably need work to handle other keybag variants.
/var/db/lockdown plists appear to no longer contain keybags. (And 0x835 was needed to decrypt them anyway.)
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Keybag ¶
type Keybag struct {
Version uint32
Type uint32
UUID []byte
HMAC []byte
Wrap uint32
Salt []byte
Iter uint32
AuxSalt []byte
AuxIter uint32
Keys []*Key
}
func (*Keybag) GetClassKey ¶
Get a class key, or nil if not available
func (*Keybag) SetPassword ¶
SetPassword decrypts the keybag, recovering some of the keys.
Click to show internal directories.
Click to hide internal directories.