Documentation
¶
Overview ¶
Package kvarchive will deserialize a key/value archive into generic objects.
This is an old work in progress package. I intended to eventually allow unmarshalling into structs, but got side tracked. Then needed this code for the "irestore" stuff.
There is a lot of stuff I've learned from writing a python version of this that hasn't made it into here yet.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UnArchive ¶
func UnArchive(r io.ReadSeeker) (rval interface{}, err error)
UnArchive deserializes a plist into a graph of generic objects (maps/arrays/etc.)
Types ¶
type KVArchive ¶
type KVArchive struct {
Archiver string `plist:"$archiver"`
Top KVArchiveTop `plist:"$top"`
Objects []interface{} `plist:"$objects"`
Version int `plist:"$version"`
// contains filtered or unexported fields
}
type KVArchiveTop ¶
Click to show internal directories.
Click to hide internal directories.